==> haskell-reflection-2.1.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-reflection/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.1.1
id: reflection-2.1.1.1-ae18c3b9d268483159599b9d645bf383
key: refle_7dvkeTy4Ejm3qeyCCfttuN
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
exposed-modules:
    Data.Reflection
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/reflection-2.1.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/reflection-2.1.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/reflection-2.1.1.1
hs-libraries: HSreflection-2.1.1.1-7dvkeTy4Ejm3qeyCCfttuN
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-reflection-2.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-reflection/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: reflection
version: 2.1.2
id: reflection-2.1.2-9b9b2f9fb5d90bced15b1aba04e6558f
key: refle_Is9SiIf9zRHG2wDNDxPaS9
license: BSD3
copyright: 2009-2013 Edward A. Kmett,
           2012 Elliott Hird,
           2004 Oleg Kiselyov and Chung-chieh Shan
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/reflection
synopsis: Reifies arbitrary terms into types that can be reflected back into terms
description:
    This package addresses the /configuration problem/ which is
    propagating configurations that are available at run-time, allowing
    multiple configurations to coexist without resorting to mutable
    global variables or '\''System.IO.Unsafe.unsafePerformIO'\''.
    .
    That package is an implementation of the ideas presented in the
    paper \"Functional Pearl: Implicit Configurations\" by Oleg Kiselyov
    and Chung-chieh Shan (<http://okmij.org/ftp/Haskell/tr-15-04.pdf original paper>).
    However, the API has been streamlined to improve performance.
    .
    Austin Seipp'\''s tutorial <https://www.fpcomplete.com/user/thoughtpolice/using-reflection Reflecting values to types and back> provides a summary of the
    approach taken by this library, along with more motivating examples.
category: Data, Reflection, Dependent Types
author: Edward A. Kmett, Elliott Hird, Oleg Kiselyov and Chung-chieh Shan
exposed: True
exposed-modules:
    Data.Reflection
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/reflection-2.1.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/reflection-2.1.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/reflection-2.1.2
hs-libraries: HSreflection-2.1.2-Is9SiIf9zRHG2wDNDxPaS9
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
haddock-interfaces: /usr/share/doc/haskell-reflection/html/reflection.haddock
haddock-html: /usr/share/doc/haskell-reflection/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
